@@ -372,10 +372,10 @@ class TensorFlowTrainer(base_trainer.Trainer):
             self.reset_metrics()
             callbacks.on_epoch_begin(epoch)
             with epoch_iterator.catch_stop_iteration():
-                for step, iterator in epoch_iterator:
-                    callbacks.on_train_batch_begin(step)
+                for begin_step, end_step, iterator in epoch_iterator:
+                    callbacks.on_train_batch_begin(begin_step)
                     logs = self.train_function(iterator)
-                    callbacks.on_train_batch_end(step, logs)
+                    callbacks.on_train_batch_end(end_step, logs)
                     if self.stop_training:
                         break
 
@@ -484,10 +484,10 @@ class TensorFlowTrainer(base_trainer.Trainer):
         logs = {}
         self.reset_metrics()
         with epoch_iterator.catch_stop_iteration():
-            for step, iterator in epoch_iterator:
-                callbacks.on_test_batch_begin(step)
+            for begin_step, end_step, iterator in epoch_iterator:
+                callbacks.on_test_batch_begin(begin_step)
                 logs = self.test_function(iterator)
-                callbacks.on_test_batch_end(step, logs)
+                callbacks.on_test_batch_end(end_step, logs)
                 if self.stop_evaluating:
                     break
         logs = self._get_metrics_result_or_logs(logs)
@@ -560,12 +560,14 @@ class TensorFlowTrainer(base_trainer.Trainer):
         callbacks.on_predict_begin()
         outputs = None
         with epoch_iterator.catch_stop_iteration():
-            for step, iterator in epoch_iterator:
-                callbacks.on_predict_batch_begin(step)
+            for begin_step, end_step, iterator in epoch_iterator:
+                callbacks.on_predict_batch_begin(begin_step)
                 data = get_data(iterator)
                 batch_outputs = self.predict_function(data)
                 outputs = append_to_outputs(batch_outputs, outputs)
-                callbacks.on_predict_batch_end(step, {"outputs": batch_outputs})
+                callbacks.on_predict_batch_end(
+                    end_step, {"outputs": batch_outputs}
+                )
                 if self.stop_predicting:
                     break
         callbacks.on_predict_end()
@@ -696,7 +698,7 @@ class TensorFlowTrainer(base_trainer.Trainer):
         # Unlike jax/torch iterator, tf iterator returns an iterator instead
         # of data batch in `iterator`.
         if iterator is not None:
-            for _, it in iterator:
+            for _, _, it in iterator:
                 maybe_distributed_data_batch = next(it)
                 has_distributed_values = tree.map_structure(
                     lambda x: isinstance(x, tf.distribute.DistributedValues),
